@@ -17,6 +17,28 @@ def test_list():
   assert list.get_element(-1) == 3
   assert list.get(1).get() == 2
 
+  list.clear()
+  assert list.to_list() == []
+
+  assert list.index(3) is None
+
+  list.push_back(1)
+  list.push_back(3)
+  list.push_back(5)
+  assert list.index(4) is None
+  assert list.index(5).prev().prev().get() == 1
+  assert list.rindex(5).prev().prev().get() == 1
+
+  clone_list = list.clone()
+  clone_list.extend([2, 4, 6])
+  assert clone_list.to_list() == [1, 3, 5, 2, 4, 6]
+
+  second_list = LinkedList()
+  second_list.extend([2, 4, 6])
+  clone_list = list.clone()
+  clone_list.extend(second_list)
+  assert clone_list.to_list() == [1, 3, 5, 2, 4, 6]
+  assert clone_list.reversed().to_list() == [6, 4, 2, 5, 3, 1]
 
 def test_insertion():
   list = LinkedList()
